pub fn resample(buf: &AudioBuffer, target_rate: u32) -> AudioBufferExpand description
Resample an AudioBuffer to the target sample rate using linear interpolation. Good enough for playback normalization — sinc resampler comes later.
pub fn resample(buf: &AudioBuffer, target_rate: u32) -> AudioBufferResample an AudioBuffer to the target sample rate using linear interpolation. Good enough for playback normalization — sinc resampler comes later.