Real-time safety enforcement.
Provides utilities for verifying the audio callback is allocation-free. The actual allocator wrapping must happen at the binary level (main.rs), not at the library level. This module provides the API and documentation.
Constants
- RT_
RULES - A list of real-time rules for documentation and enforcement.
Traits
- RtSafe
- Marker trait for types that are safe to use in the audio callback. Types that implement this promise they will never allocate, block, or do I/O.